pub struct JobMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on job resources.
It is not used directly, but through the YouTubeReporting hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_youtubereporting1 as youtubereporting1;
use youtubereporting1::{YouTubeReporting, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = YouTubeReporting::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `create(...)`, `delete(...)`, `get(...)`, `list(...)`, `reports_get(...)` and `reports_list(...)`
// to build up your call.
let rb = hub.jobs();Implementations
Sourceimpl<'a, C> JobMethods<'a, C>
impl<'a, C> JobMethods<'a, C>
Sourcepub fn reports_get(
&self,
job_id: &str,
report_id: &str,
) -> JobReportGetCall<'a, C>
pub fn reports_get( &self, job_id: &str, report_id: &str, ) -> JobReportGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the metadata of a specific report.
Arguments
jobId- The ID of the job.reportId- The ID of the report to retrieve.
Sourcepub fn reports_list(&self, job_id: &str) -> JobReportListCall<'a, C>
pub fn reports_list(&self, job_id: &str) -> JobReportListCall<'a, C>
Create a builder to help you perform the following task:
Lists reports created by a specific job. Returns NOT_FOUND if the job does not exist.
Arguments
jobId- The ID of the job.
Sourcepub fn create(&self, request: Job) -> JobCreateCall<'a, C>
pub fn create(&self, request: Job) -> JobCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a job and returns it.
Arguments
request- No description provided.
Sourcepub fn delete(&self, job_id: &str) -> JobDeleteCall<'a, C>
pub fn delete(&self, job_id: &str) -> JobDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a job.
Arguments
jobId- The ID of the job to delete.
Sourcepub fn get(&self, job_id: &str) -> JobGetCall<'a, C>
pub fn get(&self, job_id: &str) -> JobGetCall<'a, C>
Create a builder to help you perform the following task:
Gets a job.
Arguments
jobId- The ID of the job to retrieve.
Sourcepub fn list(&self) -> JobListCall<'a, C>
pub fn list(&self) -> JobListCall<'a, C>
Create a builder to help you perform the following task:
Lists jobs.